==> jc-1.4.0.tar.gz: java/awt/Panel__24AccessibleAWTPanel.h <==
// public class java.awt.Panel$AccessibleAWTPanel

// class file dependencies
// @dep_class 61b24c22f38bff85 java_awt_Component__24AccessibleAWTComponent
// @dep_class 6d5f0a9d86bc5fc4 java_awt_Container__24AccessibleAWTContainer
// @dep_class cf70181aba087445 java_awt_Panel__24AccessibleAWTPanel
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext

// header file dependencies
// @dep_header java_awt_Container__24AccessibleAWTContainer

#include "java/awt/Container__24AccessibleAWTContainer.h"

#ifndef _JC_java_awt_Panel__24AccessibleAWTPanel_H_
#define _JC_java_awt_Panel__24AccessibleAWTPanel_H_

// Forward structure declarations
struct _jc_java_awt_Panel$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleRole$object;

// Typedefs
typedef struct _jc_java_awt_Panel__24AccessibleAWTPanel$sub_refs	_jc_java_awt_Panel__24AccessibleAWTPanel$sub_refs;
typedef struct _jc_java_awt_Panel__24AccessibleAWTPanel$sub_nonrefs	_jc_java_awt_Panel__24AccessibleAWTPanel$sub_nonrefs;
typedef struct _jc_java_awt_Panel__24AccessibleAWTPanel$refs	_jc_java_awt_Panel__24AccessibleAWTPanel$refs;
typedef struct _jc_java_awt_Panel__24AccessibleAWTPanel$nonrefs	_jc_java_awt_Panel__24AccessibleAWTPanel$nonrefs;
typedef struct _jc_java_awt_Panel__24AccessibleAWTPanel$object	_jc_java_awt_Panel__24AccessibleAWTPanel$object;

typedef struct _jc_java_awt_Panel__24AccessibleAWTPanel$fields_struct	_jc_java_awt_Panel__24AccessibleAWTPanel$fields_struct;
typedef const struct _jc_java_awt_Panel__24AccessibleAWTPanel$vmethods	_jc_java_awt_Panel__24AccessibleAWTPanel$vmethods;
typedef const struct _jc_java_awt_Panel__24AccessibleAWTPanel$vtable	_jc_java_awt_Panel__24AccessibleAWTPanel$vtable;
typedef const struct _jc_java_awt_Panel__24AccessibleAWTPanel$vtype	_jc_java_awt_Panel__24AccessibleAWTPanel$vtype;

// Class fields structure
struct _jc_java_awt_Panel__24AccessibleAWTPanel$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_Panel__24AccessibleAWTPanel$fields_struct _jc_java_awt_Panel__24AccessibleAWTPanel$class_fields;

// Constructors
extern void _jc_java_awt_Panel__24AccessibleAWTPanel$method$_init$7f858abd5fff1c00(_jc_env *, struct _jc_java_awt_Panel__24AccessibleAWTPanel$object *, struct _jc_java_awt_Panel$object *);

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_java_awt_Panel__24AccessibleAWTPanel$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_java_awt_Panel__24AccessibleAWTPanel$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_Panel__24AccessibleAWTPanel$method_info$getAccessibleRole$eaa05a502d0ede18;

// Virtual methods structure
struct _jc_java_awt_Panel__24AccessibleAWTPanel$vmethods {
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_java_awt_Panel__24AccessibleAWTPanel$object *);
};

// Vtable
struct _jc_java_awt_Panel__24AccessibleAWTPanel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Container__24AccessibleAWTContainer$vmethods	java_awt_Container__24AccessibleAWTContainer;
	_jc_java_awt_Panel__24AccessibleAWTPanel$vmethods	java_awt_Panel__24AccessibleAWTPanel;
};

// Vtype
struct _jc_java_awt_Panel__24AccessibleAWTPanel$vtype {
	_jc_type			type;
	_jc_java_awt_Panel__24AccessibleAWTPanel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_Panel__24AccessibleAWTPanel$sub_refs {
	struct _jc_java_awt_Panel$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_Panel__24AccessibleAWTPanel$refs {
    _jc_java_awt_Panel__24AccessibleAWTPanel$sub_refs	java_awt_Panel__24AccessibleAWTPanel;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_refs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_Panel__24AccessibleAWTPanel$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_Panel__24AccessibleAWTPanel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Panel__24AccessibleAWTPanel$sub_nonrefs	java_awt_Panel__24AccessibleAWTPanel;
};

// Object instance structure
struct _jc_java_awt_Panel__24AccessibleAWTPanel$object {
	_jc_java_awt_Panel__24AccessibleAWTPanel$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_Panel__24AccessibleAWTPanel$vtype	*vtype;
	_jc_java_awt_Panel__24AccessibleAWTPanel$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_Panel__24AccessibleAWTPanel$vtype _jc_java_awt_Panel__24AccessibleAWTPanel$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_Panel__24AccessibleAWTPanel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_Panel__24AccessibleAWTPanel$class_object;

#endif	/* _JC_java_awt_Panel__24AccessibleAWTPanel_H_ */

==> jc-1.4.5.tar.gz: java/awt/Panel__24AccessibleAWTPanel.h <==
// public class java.awt.Panel$AccessibleAWTPanel

// class file dependencies
// @dep_class e1ad6f3c35669e42 java_awt_Component__24AccessibleAWTComponent
// @dep_class 6d5f0a9d86bc5fc4 java_awt_Container__24AccessibleAWTContainer
// @dep_class cf70181aba087445 java_awt_Panel__24AccessibleAWTPanel
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext

// header file dependencies
// @dep_header java_awt_Container__24AccessibleAWTContainer

#include "java/awt/Container__24AccessibleAWTContainer.h"

#ifndef _JC_java_awt_Panel__24AccessibleAWTPanel_H_
#define _JC_java_awt_Panel__24AccessibleAWTPanel_H_

// Forward structure declarations
struct _jc_java_awt_Panel$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleRole$object;

// Typedefs
typedef struct _jc_java_awt_Panel__24AccessibleAWTPanel$sub_refs	_jc_java_awt_Panel__24AccessibleAWTPanel$sub_refs;
typedef struct _jc_java_awt_Panel__24AccessibleAWTPanel$sub_nonrefs	_jc_java_awt_Panel__24AccessibleAWTPanel$sub_nonrefs;
typedef struct _jc_java_awt_Panel__24AccessibleAWTPanel$refs	_jc_java_awt_Panel__24AccessibleAWTPanel$refs;
typedef struct _jc_java_awt_Panel__24AccessibleAWTPanel$nonrefs	_jc_java_awt_Panel__24AccessibleAWTPanel$nonrefs;
typedef struct _jc_java_awt_Panel__24AccessibleAWTPanel$object	_jc_java_awt_Panel__24AccessibleAWTPanel$object;

typedef struct _jc_java_awt_Panel__24AccessibleAWTPanel$fields_struct	_jc_java_awt_Panel__24AccessibleAWTPanel$fields_struct;
typedef const struct _jc_java_awt_Panel__24AccessibleAWTPanel$vmethods	_jc_java_awt_Panel__24AccessibleAWTPanel$vmethods;
typedef const struct _jc_java_awt_Panel__24AccessibleAWTPanel$vtable	_jc_java_awt_Panel__24AccessibleAWTPanel$vtable;
typedef const struct _jc_java_awt_Panel__24AccessibleAWTPanel$vtype	_jc_java_awt_Panel__24AccessibleAWTPanel$vtype;

// Class fields structure
struct _jc_java_awt_Panel__24AccessibleAWTPanel$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_Panel__24AccessibleAWTPanel$fields_struct _jc_java_awt_Panel__24AccessibleAWTPanel$class_fields;

// Constructors
extern void _jc_java_awt_Panel__24AccessibleAWTPanel$method$_init$7f858abd5fff1c00(_jc_env *, struct _jc_java_awt_Panel__24AccessibleAWTPanel$object *, struct _jc_java_awt_Panel$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_java_awt_Panel__24AccessibleAWTPanel$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_java_awt_Panel__24AccessibleAWTPanel$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_Panel__24AccessibleAWTPanel$method_info$getAccessibleRole$eaa05a502d0ede18;

// Virtual methods structure
struct _jc_java_awt_Panel__24AccessibleAWTPanel$vmethods {
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_java_awt_Panel__24AccessibleAWTPanel$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_Panel__24AccessibleAWTPanel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Container__24AccessibleAWTContainer$vmethods	java_awt_Container__24AccessibleAWTContainer;
	_jc_java_awt_Panel__24AccessibleAWTPanel$vmethods	java_awt_Panel__24AccessibleAWTPanel;
};

// Vtype
struct _jc_java_awt_Panel__24AccessibleAWTPanel$vtype {
	_jc_type			type;
	_jc_java_awt_Panel__24AccessibleAWTPanel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_Panel__24AccessibleAWTPanel$sub_refs {
	struct _jc_java_awt_Panel$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_Panel__24AccessibleAWTPanel$refs {
    _jc_java_awt_Panel__24AccessibleAWTPanel$sub_refs	java_awt_Panel__24AccessibleAWTPanel;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_refs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_Panel__24AccessibleAWTPanel$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_Panel__24AccessibleAWTPanel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Panel__24AccessibleAWTPanel$sub_nonrefs	java_awt_Panel__24AccessibleAWTPanel;
};

// Object instance structure
struct _jc_java_awt_Panel__24AccessibleAWTPanel$object {
	_jc_java_awt_Panel__24AccessibleAWTPanel$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_Panel__24AccessibleAWTPanel$vtype	*vtype;
	_jc_java_awt_Panel__24AccessibleAWTPanel$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_Panel__24AccessibleAWTPanel$vtype _jc_java_awt_Panel__24AccessibleAWTPanel$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_Panel__24AccessibleAWTPanel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_Panel__24AccessibleAWTPanel$class_object;

#endif	/* _JC_java_awt_Panel__24AccessibleAWTPanel_H_ */
